from distutils.core import setup

setup(
	name = 'pugplay',
	version = '1.0.0',
	py_modules = ['pugplay'],
	author = 'DevPug',
	author_email = 'deviant.pug@gmail.com',
	url = 'devpug.wordpress.com',
	description = 'From HFP ch 2, prints out theatre scripts'
	)

